import mongoose, {ObjectId, mongo} from 'mongoose';
import dotenv from 'dotenv';
import UserModel from './models/user';
import ArtistModel from './models/artist';
import AlbumModel from './models/album';
import TrackModel from './models/track';
dotenv.config();

mongoose.connect(process.env.MONGO_URL + '/MyPlayer');

const db = mongoose.connection;

db.once('open', async () => {
	try {
		await db.dropCollection('users');
		await db.dropCollection('artists');
		await db.dropCollection('albums');
		await db.dropCollection('tracks');
	} catch (e) {
		console.log('Collections were not present, skipping drop...');
	}

	await UserModel.create(
		{
			username: 'alen',
			password: '1',
		},
		{
			username: 'danil',
			password: '2',
		}
	);

	const firstArtistId = new mongoose.Types.ObjectId();
	const secondArtisId = new mongoose.Types.ObjectId();

	await ArtistModel.create(
		{
			_id: firstArtistId,
			info: 'Aubrey Drake Graham is a Canadian rapper and singer. An influential global figure in contemporary popular music, Drake has been credited for popularizing singing and R&B sensibilities in hip hop.',
			name: 'Drake',
			photo: 'drake.jpg',
		},
		{
			_id: secondArtisId,
			info: 'Marshall Bruce Mathers III, known professionally as Eminem, is an American rapper, songwriter, and record producer. He is credited with popularizing hip hop in middle America and is critically acclaimed as one of the greatest rappers of all time.',
			name: 'Eminem',
			photo: 'eminem.png',
		}
	);

	const firstAlbumId = new mongoose.Types.ObjectId();
	const secondAlbumId = new mongoose.Types.ObjectId();
	const thirdAlbumId = new mongoose.Types.ObjectId();

	await AlbumModel.create(
		{
			_id: firstAlbumId,
			artist: firstArtistId,
			image: 'album1.jpg',
			year: 2001,
			name: 'Room for Improvement',
		},
		{
			_id: secondAlbumId,
			artist: firstArtistId,
			image: 'album2.jpg',
			year: 2005,
			name: 'Comeback Season',
		},
		{
			_id: thirdAlbumId,
			artist: secondArtisId,
			image: 'album3.jpg',
			year: 2011,
			name: 'One fortune',
		}
	);

	await TrackModel.create(
		{
			album: firstAlbumId,
			duration: '2:56',
			name: 'Predator',
		},
		{
			album: secondAlbumId,
			duration: '3:10',
			name: 'Mommy',
		}
	);

	db.close();
});
